==> ember-0.5.7.tar.bz2: ember-0.5.7/src/components/ogre/environment/OceanAction.h <==
/*
 Copyright (C) 2009 Erik Hjortsberg <erik.hjortsberg@gmail.com>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef OCEANACTION_H_
#define OCEANACTION_H_

#include "components/entitymapping/Actions/Action.h"

namespace EmberOgre
{
class EmberEntity;
namespace Environment
{


/**
 * @author Erik Hjortsberg <erik.hjortsberg@gmail.com>
 *
 * @brief Creates an OceanRepresentation and binds it to an entity.
 */
class OceanAction: public Ember::EntityMapping::Actions::Action
{
public:
	/**
	 * @brief Ctor.
	 * @param entity The entity for which an OceanRepresentation should be created for.
	 */
	OceanAction(EmberEntity& entity);

	/**
	 * @brief Dtor.
	 */
	virtual ~OceanAction();

	/**
	 * @copydoc Ember::EntityMapping::Actions::Action::activate()
	 */
	virtual void activate();

	/**
	 * @copydoc Ember::EntityMapping::Actions::Action::deactivate()
	 */
	virtual void deactivate();

private:

	EmberEntity& mEntity;
};
}
}

#endif /* OCEANACTION_H_ */

==> ember-0.6.0.tar.bz2: ember-0.6.0/src/components/ogre/environment/OceanAction.h <==
/*
 Copyright (C) 2009 Erik Hjortsberg <erik.hjortsberg@gmail.com>

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef OCEANACTION_H_
#define OCEANACTION_H_

#include "components/entitymapping/Actions/Action.h"

namespace EmberOgre
{
class EmberEntity;
namespace Environment
{


/**
 * @author Erik Hjortsberg <erik.hjortsberg@gmail.com>
 *
 * @brief Creates an OceanRepresentation and binds it to an entity.
 */
class OceanAction: public Ember::EntityMapping::Actions::Action
{
public:
	/**
	 * @brief Ctor.
	 * @param entity The entity for which an OceanRepresentation should be created for.
	 */
	OceanAction(EmberEntity& entity);

	/**
	 * @brief Dtor.
	 */
	virtual ~OceanAction();

	/**
	 * @copydoc Ember::EntityMapping::Actions::Action::activate()
	 */
	virtual void activate(Ember::EntityMapping::ChangeContext& context);

	/**
	 * @copydoc Ember::EntityMapping::Actions::Action::deactivate()
	 */
	virtual void deactivate(Ember::EntityMapping::ChangeContext& context);

private:

	EmberEntity& mEntity;
};
}
}

#endif /* OCEANACTION_H_ */
